__version__ = '1.1'

from registrar import Registrar
from directory import Directory
from dining import Dining
from transit import Transit
from news import News
from laundry import Laundry
from map import Map
